//
//  ViewController.swift
//  TestSciChart
//
//  Created by Vlad Badea on 8/27/23.
//

import Cocoa
import SciChart

class ViewController: NSViewController {
    
    private var button: NSButton!
    private let chartSurface = SCIChartSurface()
    private let xAxis = SCINumericAxis()
    private let yAxis = SCINumericAxis()

    override func viewDidLoad() {
        super.viewDidLoad()
        
        chartSurface.translatesAutoresizingMaskIntoConstraints = false
        view.addSubview(chartSurface)
        
        button = NSButton(title: "Set visibleRange to dataRange", target: self, action: #selector(buttonClicked(_:)))
        button.translatesAutoresizingMaskIntoConstraints = false
        view.addSubview(button)
        
        NSLayoutConstraint.activate([
            chartSurface.topAnchor.constraint(equalTo: view.topAnchor),
            chartSurface.leadingAnchor.constraint(equalTo: view.leadingAnchor),
            chartSurface.trailingAnchor.constraint(equalTo: view.trailingAnchor),
            chartSurface.bottomAnchor.constraint(equalTo: view.bottomAnchor),
            button.centerXAnchor.constraint(equalTo: view.centerXAnchor),
            button.topAnchor.constraint(equalTo: view.topAnchor, constant: 20)
        ])
                
        let dataSeries = SCIXyDataSeries(xType: .double, yType: .double)
        let count = 100
        let xValues = SCIDoubleValues(capacity: count)
        let yValues = SCIDoubleValues(capacity: count)
        for i in 0 ..< count {
            xValues.add(Double(i))
            yValues.add(Double.random(in: 0..<50))
        }
        dataSeries.append(x: xValues, y: yValues)
        
        let rSeries = SCIFastLineRenderableSeries()
        rSeries.dataSeries = dataSeries
        
        SCIUpdateSuspender.usingWith(chartSurface) {
            self.chartSurface.xAxes.add(self.xAxis)
            self.chartSurface.yAxes.add(self.yAxis)
            self.chartSurface.renderableSeries.add(rSeries)
            self.chartSurface.chartModifiers.add(items: SCIZoomPanModifier(), SCIPinchZoomModifier())
        }
    }
    
    @IBAction func buttonClicked(_ sender: Any?) {
        print("xAxis.dataRange is \(xAxis.dataRange)   yAxis.dataRange is \(yAxis.dataRange)")
        print("xAxis.visibleRange is \(xAxis.visibleRange)   yAxis.visibleRange is \(yAxis.visibleRange)")
        xAxis.visibleRange = xAxis.dataRange
        yAxis.visibleRange = yAxis.dataRange
    }
}
